@@ -7,11 +7,9 @@
 
 # Hacked out of the file-based rc script.
 
-
 CFGFILE="/etc/runlevel.conf"
 BAKCFG="/etc/runlevel.fallback"
-LOCKFILE="/etc/runlevel.lock"
-TMPFILE="/etc/runlevel.tmp"
+LOCKFILE="/var/lock/runlevel.lock"
 
 i=0
 while [ -f "$LOCKFILE" -a "$previous" != "N" ]
@@ -30,7 +28,7 @@ do
         exit 1
     fi
     sleep 2
-    let i+=1
+    i=$(($i + 1))
 done
 
 cd /etc
